"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/classCallCheck"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/createClass"));

var _foo = _interopRequireDefault(require("foo"));

let Example = /*#__PURE__*/function () {
  function Example() {
    (0, _classCallCheck2.default)(this, Example);
  }

  (0, _createClass2.default)(Example, [{
    key: "method",
    value: function method() {}
  }]);
  return Example;
}();
